const AWS = require('aws-sdk');
const ses = new AWS.SES();
exports.handler = (event, context, callback) => {
   var eventdata = JSON.parse(event.body);
   sendEmail(eventdata, context.awsRequestId, callback);
};

function errorResponse(errorMessage, awsRequestId, callback) {
   callback(null, {
       statusCode: 500,
       body: JSON.stringify({
           Error: errorMessage,
           Reference: awsRequestId,
       }),
       headers: {
           'Access-Control-Allow-Origin': '*',
       },
   });
}

function sendEmail(data, awsRequestId, callback) {
   var sender = '<SEND-EMAIL-ADDRESS>';
   var receiver = '<RECEIVE-EMAIL-ADDRESS>';
   var name = data.env.AS2UserName.trim();
   var params = {
       Destination: {
           ToAddresses: [receiver]
       },
       Message: {
           Body: {
               Text: {
                   Data:
                       'User Information\n\n' +
                       'Username: ' + name + '\n' +
                       'User Email: ' + data.email + '\n' +
                       'StackName: ' + data.env.StackName + '\n' +
                       'FleetName: ' + data.env.FleetName + '\n' +
                       'InstanceID: ' + data.env.InstanceID + '\n' +
                       'Application Log Archive S3 Path: ' + data.env.AppLogPath + '\n' +
                       'Issue Reporter Log S3 Path: ' + data.env.IRLogPath + '\n\n' +
                       'User Description of the Issue: ' + data.description
                       ,
                   Charset: 'UTF-8'
               }
           },
           Subject: {
               Data: 'User ' + name + ' ' + 'reported and issue with application ' + data.env.App,
               Charset: 'UTF-8'
           }
       },
       Source: sender
   };
   console.log("Sending Email.");
   ses.sendEmail(params, function (err) {
       if (err) errorResponse(err, awsRequestId, callback);
       else callback(null, {
           statusCode: 201,
           body: JSON.stringify({
               Message: "Success",
               Reference: awsRequestId,
           }),
           headers: {
               'Access-Control-Allow-Origin': '*',
           },
       });
   });
}